@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::AI;
 BEGIN {
-  $Games::Risk::AI::VERSION = '3.101110';
+  $Games::Risk::AI::VERSION = '3.101370';
 }
 # ABSTRACT: base class for all ais
 
@@ -297,7 +297,7 @@ Games::Risk::AI - base class for all ais
 
 =head1 VERSION
 
-version 3.101110
+version 3.101370
 
 =head1 SYNOPSIS
 
@@ -388,17 +388,6 @@ provide sane defaults.
 
 L<Games::Risk>.
 
-=head1 AUTHOR
-
-Jerome Quelin, C<< <jquelin at cpan.org> >>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2008 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU GPLv3+.
-
 =head1 AUTHOR
 
   Jerome Quelin
@@ -417,4 +406,3 @@ This is free software, licensed under:
 __END__
 
 
-
