@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::Card;
 BEGIN {
-  $Games::Risk::Card::VERSION = '3.101110';
+  $Games::Risk::Card::VERSION = '3.101370';
 }
 # ABSTRACT: map card
 
@@ -52,7 +52,7 @@ Games::Risk::Card - map card
 
 =head1 VERSION
 
-version 3.101110
+version 3.101370
 
 =head1 SYNOPSIS
 
@@ -107,17 +107,6 @@ Remove all circular references of C<$card>, to prevent memory leaks.
 
 L<Games::Risk>.
 
-=head1 AUTHOR
-
-Jerome Quelin, C<< <jquelin at cpan.org> >>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2008 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU GPLv3+.
-
 =head1 AUTHOR
 
   Jerome Quelin
@@ -136,4 +125,3 @@ This is free software, licensed under:
 __END__
 
 
-
