@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::Continent;
 BEGIN {
-  $Games::Risk::Continent::VERSION = '3.101110';
+  $Games::Risk::Continent::VERSION = '3.101370';
 }
 # ABSTRACT: continent object
 
@@ -88,7 +88,7 @@ Games::Risk::Continent - continent object
 
 =head1 VERSION
 
-version 3.101110
+version 3.101370
 
 =head1 SYNOPSIS
 
@@ -160,17 +160,6 @@ Return true if C<$player> is the owner of all C<$continent>'s countries.
 
 L<Games::Risk>.
 
-=head1 AUTHOR
-
-Jerome Quelin, C<< <jquelin at cpan.org> >>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2008 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU GPLv3+.
-
 =head1 AUTHOR
 
   Jerome Quelin
@@ -190,4 +179,3 @@ __END__
 
 
 
-
