@@ -13,12 +13,10 @@ use warnings;
 
 package Games::Risk::GUI::Startup;
 BEGIN {
-  $Games::Risk::GUI::Startup::VERSION = '3.101110';
+  $Games::Risk::GUI::Startup::VERSION = '3.101370';
 }
 # ABSTRACT: startup window
 
-use Games::Risk::GUI::Constants;
-use Games::Risk::Resources qw{ image maps };
 use List::Util     qw{ shuffle };
 use List::MoreUtils qw{ any };
 use POE             qw{ Loop::Tk };
@@ -27,6 +25,10 @@ use Tk;
 use Tk::Balloon;
 use Tk::BrowseEntry;
 use Tk::Font;
+use Tk::Sugar;
+
+use Games::Risk::I18N      qw{ T };
+use Games::Risk::Resources qw{ image maps };
 
 use constant K => $poe_kernel;
 
@@ -52,16 +54,16 @@ Readonly my @COLORS => (
     #'#A3E3ED',  # blizzard blue
 );
 Readonly my @NAMES => (
-    'Napoleon Bonaparte',   # france,   1769  - 1821
-    'Staline',              # russia,   1878  - 1953
-    'Alexander the Great',  # greece,   356BC - 323BC
-    'Julius Caesar',        # rome,     100BC - 44BC
-    'Attila',               # hun,      406   - 453
-    'Genghis Kahn',         # mongolia, 1162  - 1227
-    'Charlemagne',          # france,   747   - 814
-    'Saladin',              # iraq,     1137  - 1193
-    'Otto von Bismarck',    # germany,  1815  - 1898
-    'Ramses II',            # egypt,    1303BC - 1213BC
+    T('Napoleon Bonaparte'),   # france,   1769  - 1821
+    T('Staline'),              # russia,   1878  - 1953
+    T('Alexander the Great'),  # greece,   356BC - 323BC
+    T('Julius Caesar'),        # rome,     100BC - 44BC
+    T('Attila'),               # hun,      406   - 453
+    T('Genghis Kahn'),         # mongolia, 1162  - 1227
+    T('Charlemagne'),          # france,   747   - 814
+    T('Saladin'),              # iraq,     1137  - 1193
+    T('Otto von Bismarck'),    # germany,  1815  - 1898
+    T('Ramses II'),            # egypt,    1303BC - 1213BC
 );
 
 
@@ -138,7 +140,7 @@ sub _onpriv_check_errors {
         $h->{error} = undef;
 
         # allow start to be clicked
-        $h->{button}{start}->configure(@ENON);
+        $h->{button}{start}->configure(enabled);
         $top->bind('<Key-Return>', $s->postback('_but_start'));
     }
 
@@ -146,27 +148,27 @@ sub _onpriv_check_errors {
     my %colors;
     @colors{ map { $_->{color} } @players } = (0) x @players;
     $colors{ $_->{color} }++ for @players;
-    $errstr = 'Two players cannot have the same color.'
+    $errstr = T('Two players cannot have the same color.')
         if any { $colors{$_} > 1 } keys %colors;
 
     # 2 players cannot have the same name
     my %names;
     @names{ map { $_->{name} } @players } = (0) x @players;
     $names{ $_->{name} }++ for @players;
-    $errstr = 'Two players cannot have the same name.'
+    $errstr = T('Two players cannot have the same name.')
         if any { $names{$_} > 1 } keys %names;
 
     # human players
-    my $nbhuman = grep { $_->{type} eq 'Human' } @players;
-    $errstr = 'Cannot have more than one human player.'            if $nbhuman > 1;
-    $errstr = 'Game without any human player not (yet) supported.' if $nbhuman < 1;
+    my $nbhuman = grep { $_->{type} eq T('Human') } @players;
+    $errstr = T('Cannot have more than one human player.')            if $nbhuman > 1;
+    $errstr = T('Game without any human player not (yet) supported.') if $nbhuman < 1;
 
     # all players should have a name
-    $errstr = 'A player cannot have an empty name.'
+    $errstr = T('A player cannot have an empty name.')
         if any { $_->{name} eq '' } @players;
 
     # there should be at least 2 players
-    $errstr = 'Game should have at least 2 players.' if scalar @players < 2;
+    $errstr = T('Game should have at least 2 players.') if scalar @players < 2;
 
     # check if there are some errors
     if ( $errstr ) {
@@ -174,10 +176,10 @@ sub _onpriv_check_errors {
         $h->{error} = $h->{frame}{players}->Label(
             -bg => 'red',
             -text => $errstr,
-        )->pack(@TOP, @FILLX);
+        )->pack(top, fillx);
 
         # prevent start to be clicked
-        $h->{button}{start}->configure(@ENOFF);
+        $h->{button}{start}->configure(disabled);
         $top->bind('<Key-Return>', undef);
     }
 }
@@ -195,7 +197,7 @@ sub _onpriv_check_nb_players {
     my @players = grep { defined $_ } @$players;
 
     # check whether we can add another player
-    my @config = ( scalar(@players) >= 10 ) ? @ENOFF : @ENON;
+    my @config = ( scalar(@players) >= 10 ) ? (disabled) : (enabled);
     $h->{button}{add_player}->configure(@config);
 }
 
@@ -209,7 +211,7 @@ sub _onpriv_check_nb_players {
 sub _onpriv_load_defaults {
     # FIXME: hardcoded
     my @names  = ($ENV{USER}, shuffle @NAMES );
-    my @types  = ('Human', ('Computer, easy')x1, ('Computer, hard')x2);
+    my @types  = (T('Human'), (T('Computer, easy'))x1, (T('Computer, hard'))x2);
     my @colors = @COLORS;
     foreach my $i ( 0..$#types ) {
         K->yield('_new_player', $names[$i], $types[$i], $colors[$i]);
@@ -228,15 +230,15 @@ sub _onpriv_new_player {
     my ($name, $type, $color) = @args;
     my $players = $h->{players};
     my $num = scalar @$players;
-    my @choices = ( 'Human', 'Computer, easy', 'Computer, hard' );
+    my @choices = ( T('Human'), T('Computer, easy'), T('Computer, hard') );
 
     # the frame
     $players->[$num]{name}  = $name;
     $players->[$num]{type}  = $type;
     $players->[$num]{color} = $color;
     my $fpl = $h->{frame}{players}->Frame
-        ->pack(@TOP, @FILLX, -before=>$h->{button}{add_player});
-    my $f = $fpl->Frame(-bg=>$color)->pack(@LEFT, @FILLX);
+        ->pack(top, fillx, -before=>$h->{button}{add_player});
+    my $f = $fpl->Frame(-bg=>$color)->pack(left, fillx);
     $players->[$num]{line}  = $fpl;
     $players->[$num]{frame} = $f;
     $f->Entry(
@@ -244,7 +246,7 @@ sub _onpriv_new_player {
         -validate     => 'all',
         -vcmd         => sub { $s->postback('_check_errors')->(); 1; },
         #-highlightbackground => $color,
-    )->pack(@LEFT,@XFILLX);
+    )->pack(left,xfillx);
     my $be = $f->BrowseEntry(
         -variable           => \$players->[$num]{type},
         -background         => $color,
@@ -253,7 +255,7 @@ sub _onpriv_new_player {
         -state              => 'readonly',
         -disabledforeground => 'black',
         -browsecmd          => $s->postback('_check_errors'),
-    )->pack(@LEFT);
+    )->pack(left);
     my $bc = $f->Button(
         -bg               => $color,
         -fg               => 'white',
@@ -261,8 +263,8 @@ sub _onpriv_new_player {
         -activeforeground => 'white',
         -image            => image('paintbrush'),
         -command          => $s->postback('_but_color', $num),
-    )->pack(@LEFT);
-    my $ld = $fpl->Label(-image=>image('fileclose16'))->pack(@LEFT);
+    )->pack(left);
+    my $ld = $fpl->Label(-image=>image('fileclose16'))->pack(left);
     $ld->bind('<1>', $s->postback('_but_delete', $num));
     $players->[$num]{be_type}   = $be;
     $players->[$num]{but_color} = $bc;
@@ -313,8 +315,8 @@ sub _onpriv_start {
         -bg   => 'black',
         -fg   => 'white',
         -font => $font,
-        -text => 'New game',
-    )->pack(@TOP,@PAD20,@FILLX);
+        -text => T('New game'),
+    )->pack(top,pad20,fillx);
 
     #-- various resources
 
@@ -324,39 +326,39 @@ sub _onpriv_start {
     #-- map selection
     my @choices = maps();
     $h->{map} = 'risk';
-    my $fmap = $top->Frame->pack(@TOP, @XFILL2, @PAD20);
-    $fmap->Label(-text=>'Map', -anchor=>'w')->pack(@TOP, @FILLX);
+    my $fmap = $top->Frame->pack(top, xfill2, pad20);
+    $fmap->Label(-text=>'Map', -anchor=>'w')->pack(top, fillx);
     $fmap->BrowseEntry(
         -variable           => \$h->{map},
         -listheight         => scalar(@choices)+1,
         -choices            => \@choices,
         -state              => 'readonly',
         -disabledforeground => 'black',
-    )->pack(@TOP);
+    )->pack(top );
 
     #-- frame for players
-    my $fpl = $top->Frame->pack(@TOP, @XFILL2, @PAD20);
-    $fpl->Label(-text=>'Players', -anchor=>'w')->pack(@TOP, @FILLX);
+    my $fpl = $top->Frame->pack(top, xfill2, pad20);
+    $fpl->Label(-text=>'Players', -anchor=>'w')->pack(top, fillx);
     $h->{button}{add_player} = $fpl->Button(
-        -text    => 'New player...',
+        -text    => T('New player...'),
         -command => $s->postback('_but_new_player'),
-    )->pack(@TOP,@FILLX);
+    )->pack(top,fillx);
     $h->{frame}{players} = $fpl;
     K->yield('_load_defaults');
 
     #-- bottom frame
-    my $fbot = $top->Frame->pack(@BOTTOM, @FILLX, @PAD20);
+    my $fbot = $top->Frame->pack(bottom, fillx, pad20);
     my $b_start = $h->{button}{start} = $fbot->Button(
-        -text => 'Start game',
+        -text => T('Start game'),
         -command => $s->postback('_but_start'),
     );
     my $b_quit = $fbot->Button(
-        -text => 'Quit',
+        -text => T('Quit'),
         -command => $s->postback('_but_quit'),
     );
     # pack after creation, to have clean focus order
-    $b_quit->pack(@RIGHT,@PAD1);
-    $b_start->pack(@RIGHT,@PAD1);
+    $b_quit->pack(right,pad1);
+    $b_start->pack(right,pad1);
 
     # window binding
     $top->bind('<Key-Return>', $s->postback('_but_start'));
@@ -450,7 +452,7 @@ sub _ongui_but_new_player {
     my $color = ( shuffle keys %colors )[0];
 
     # default type
-    my $type = 'Computer, hard';
+    my $type = T('Computer, hard');
 
     # create new player
     K->yield('_new_player', $name, $type, $color);
@@ -504,7 +506,7 @@ Games::Risk::GUI::Startup - startup window
 
 =head1 VERSION
 
-version 3.101110
+version 3.101370
 
 =head1 SYNOPSIS
 
@@ -523,17 +525,6 @@ of the GUI. It allows to design the new game to be played.
 
 L<Games::Risk>.
 
-=head1 AUTHOR
-
-Jerome Quelin, C<< <jquelin at cpan.org> >>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2008 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU GPLv3+.
-
 =head1 AUTHOR
 
   Jerome Quelin
@@ -553,4 +544,3 @@ __END__
 
 
 
-
