@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::Player;
 BEGIN {
-  $Games::Risk::Player::VERSION = '3.101110';
+  $Games::Risk::Player::VERSION = '3.101370';
 }
 # ABSTRACT: risk player
 
@@ -187,7 +187,7 @@ Games::Risk::Player - risk player
 
 =head1 VERSION
 
-version 3.101110
+version 3.101370
 
 =head1 SYNOPSIS
 
@@ -279,17 +279,6 @@ with the number of owned territories, as well as the number of armies.
 
 L<Games::Risk>.
 
-=head1 AUTHOR
-
-Jerome Quelin, C<< <jquelin at cpan.org> >>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2008 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU GPLv3+.
-
 =head1 AUTHOR
 
   Jerome Quelin
@@ -310,4 +299,3 @@ __END__
 
 
 
-
