@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::Resources;
 BEGIN {
-  $Games::Risk::Resources::VERSION = '3.101110';
+  $Games::Risk::Resources::VERSION = '3.101370';
 }
 # ABSTRACT: utility module to load bundled resources
 
@@ -143,7 +143,7 @@ Games::Risk::Resources - utility module to load bundled resources
 
 =head1 VERSION
 
-version 3.101110
+version 3.101370
 
 =head1 SYNOPSIS
 
@@ -198,17 +198,6 @@ Return the names of all the maps bundled with C<Games::Risk>.
 
 L<Games::Risk>.
 
-=head1 AUTHOR
-
-Jerome Quelin, C<< <jquelin at cpan.org> >>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2008 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU GPLv3+.
-
 =head1 AUTHOR
 
   Jerome Quelin
@@ -227,4 +216,3 @@ This is free software, licensed under:
 __END__
 
 
-
